# encoding: utf-8
require 'forwardable'
require 'fleetly/request'
require 'fleetly/user'
require 'fleetly/activity'
require 'fleetly/logitem'

module Fleetly
  class Client
    extend Forwardable

    include Request
    include User
    include Activity
    include Logitem

    attr_reader :api_url, :token

    ##
    # Create a new Fleetly::Client object
    #
    # @params options[Hash]
    def initialize(options={})
      @api_url = options[:api_url] || Fleetly.api_url
      @token = options[:token] || Fleetly.token
    end

    ##
    # Create a Faraday::Connection object
    #
    # @return [Faraday::Connection]
    def connection
      params = {}
      @connection = Faraday.new(url: api_url, params: params, headers: default_headers) do |faraday|
        faraday.use FaradayMiddleware::Mashify
        faraday.use FaradayMiddleware::ParseJson, content_type: /\bjson$/
        faraday.use FaradayMiddleware::FollowRedirects
        faraday.adapter Faraday.default_adapter
      end
    end

    private

    def default_headers
      headers = {
        accept: 'application/json',
        content_type: 'application/json',
        user_agent: "Ruby Gem by Validic #{Fleetly::VERSION}"
      }
    end
  end
end
